/*
Controvery of Public Library Items
 By James Schaffer
 */

import treemap.*;

Treemap map;

int radius = 100;
int xPosition  = 20;

float [][] dataMatrix = null;
float maxValue ;
int rectWidth = 10;
int rectHeight = 20;

int columnCount = 90;
int rowCount = 1;

int drawSpaceWidth, drawSpaceHeight;
int horizontalMargin, verticalMargin;

PFont headerFont = createFont( "Arial", 20, true);
PFont legendFont = createFont( "Calibri", 14, true);

public static String headerDodString = "";
public static String dodString = "";

BucketGrid myGrid;

Table rawTable;

void setup() {

  size( 1870, 950);
  smooth();
//  frameRate( 10 );      
   myGrid = new BucketGrid( loadTable( "ddc22-summaries10-eng.csv", "header" ) );

  rawTable = loadTable( "100-999.csv", "header" );
  rawTable.addColumn( "controversy" ); //  bibNumber,title,topic,pops,pages,rating,checkoutAverage,checkoutVariance
  
  for ( TableRow row : rawTable.rows() ) {
    myGrid.addBib( row );
  }
  
  println( myGrid.summary() );
  myGrid.layout( "topic", "pops", columnCount, rowCount, 100, 0, 1000, 0 );

  dataMatrix = new float[ myGrid.buckets.length ][ myGrid.buckets[ 0 ].length ];

//  for ( int i = 0; i < columnCount; i++) {
//    for ( int j = 0; j < rowCount; j++) {
//      dataMatrix[ i ][ j ] = myGrid.buckets[ i ][ j ].getAverageRating();                
//      print( dataMatrix[ i ][ j ] + " ");
//    }
//    println();
//  }
  
  maxValue = myGrid.maxs.get( "rating" );

  drawSpaceWidth = 1600;//rectWidth * columnCount;
  drawSpaceHeight = 800; //rectHeight * rowCount;

  horizontalMargin = ( width - drawSpaceWidth ) / 2;
  verticalMargin = ( height - drawSpaceHeight ) / 2; 

  BibTreeMap mapData = new BibTreeMap();
  for ( int i = 0; i < myGrid.buckets.length; i++ ) {
    if ( myGrid.buckets[ i ][ 0 ].getAverage( "rating" ) > 0 ) {
      mapData.addTopic( myGrid.buckets[ i ][ 0 ], myGrid );
      println( myGrid.buckets[ i ][ 0 ].getAverage( "rating" ) );
    }
  }
  
  mapData.finishAdd();
  map = new Treemap( mapData, horizontalMargin * 1.5, verticalMargin, drawSpaceWidth, drawSpaceHeight );
//  noLoop( );

  println( " setup done" );
  
}

void draw() {

//  -------------------------------  TREE MAP ------------------------------------------
  background(0);
  colorMode(RGB);
  textAlign( LEFT );
  textFont( headerFont );  
  text( "Controversy of Books for Each Dewey Topic (size indicates total checkouts)", 15, 25 );

  textFont( legendFont );
  textAlign( LEFT, CENTER );
  text( "less controversial", drawSpaceWidth + horizontalMargin - 400, verticalMargin / 2 - 25 );
  textAlign( RIGHT, CENTER );
  text( "more controversial", drawSpaceWidth + horizontalMargin, verticalMargin / 2 - 25 );

  colorMode(RGB);
  noStroke();
  for ( int i = 0; i < 100; i += 1 ) {
    fill( 0, 55 + 200 * i / 100, 55 + 200 * i / 100 );
    rect( drawSpaceWidth + horizontalMargin - 400 + i * 4, verticalMargin / 2 - 15, 4, 30 );
  }
  
  stroke( 255 );
  strokeWeight( 1 );
  noFill();
  textAlign( CENTER, TOP);
  rect( horizontalMargin * 0.1, verticalMargin, horizontalMargin * 1.3, drawSpaceHeight );
  fill( 255 );
  textFont( headerFont );
  text( headerDodString, horizontalMargin * 0.2, verticalMargin * 1.1, horizontalMargin * 1.1, verticalMargin * 2 );
  textFont( legendFont );
  text( dodString, horizontalMargin * 0.2, verticalMargin * 3.2, horizontalMargin * 1.1, drawSpaceHeight - verticalMargin * 3.2 );
  
  map.draw();

//  textFont( headerFont );
//  textAlign(CENTER, CENTER );
//  text( "Popularity", horizontalMargin / 2, verticalMargin + drawSpaceHeight / 2 );
//  text( "Subject", horizontalMargin + drawSpaceWidth / 2, verticalMargin + drawSpaceHeight  + verticalMargin / 2 );
//
//  textFont( legendFont );
//  textAlign( RIGHT, CENTER );
//  for ( int i = 0; i < columnCount; i++ ) {
//    if ( i == 0 )
//      text( "<10", horizontalMargin - 10, verticalMargin + rectHeight / 2 + i * rectHeight );
//    else if ( i == columnCount - 1 )
//      text( "400+", horizontalMargin - 10, verticalMargin + rectHeight / 2 + i * rectHeight );
//    else
//      text( "" + i * 10 + "-" + ( i + 1 ) * 10, horizontalMargin - 10, verticalMargin + rectHeight / 2 + i * rectHeight );
//  }
//
//  textAlign( LEFT, CENTER );
//  rotate( PI / 2 );
//  for ( int i = 0; i < rowCount; i++ ) {
//    text( "" + i * 10, verticalMargin + drawSpaceHeight + 5, -1 * ( horizontalMargin + rectHeight / 2 + i * rectWidth ) );
//  }
//  rotate( - PI / 2 );
//
  

//  -------------------------------  2D GRID ------------------------------------------
//  stroke( 255 );
//  translate( horizontalMargin, verticalMargin );
//  for ( int  i = 0; i<  columnCount; i++) {
//    for ( int  j = 0; j < rowCount; j++) {      
//      if ( dataMatrix[ i ][ j ] != -1 ) {
//        fill( 0, 55 + 200 * dataMatrix[ i ][ j ] / maxValue, 55 + 200 * dataMatrix[ i ][ j ] / maxValue );                      
//        rect( i * rectWidth, j * rectHeight, rectWidth, rectHeight );
//      }
//    }
//  }
}

